=====
Usage
=====
Command line interface
----------------------
To use NiFi's FlowFile Format command line tool:

.. click:: nifi.flowfile.cli:flowfile
  :prog: nifi flowfile
  :show-nested:

Library Usage
-------------
To use NiFi's FlowFile Format in a project::

    import nifi.flowfile